==> SCA_SDO-1.1.0.tgz: SCA_SDO-1.1.0/commonj/sdo/TypeList.cpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/* $Rev: 452786 $ $Date: 2006/11/24 10:44:27 $ */

#ifndef SDO_EXPORTS
    #define SDO_EXPORTS
#endif

#include "commonj/sdo/export.h"
#include <iostream>
#include "commonj/sdo/Property.h"
#include "commonj/sdo/Type.h"
#include "commonj/sdo/TypeList.h"
#include "commonj/sdo/Logger.h"

using namespace std;

namespace commonj{
namespace sdo {


/** TypeList provides access to a list of Types.
 *
 * The data factory can return a list of types available. This
 * class wraps that list and provides access to Types by 
 * iteration
 */

SDO_API TypeList::TypeList(std::vector<const Type*> p) : plist (p)
{
}

SDO_API TypeList::TypeList(const TypeList &pin)
{
    plist = std::vector<const Type*>(pin.getVec());
}

SDO_API TypeList::TypeList()
{
}

SDO_API TypeList::~TypeList()
{
}


SDO_API const Type& TypeList::operator[] (int pos) const
{
    return *plist[pos];
}

SDO_API int TypeList::size () const
{
    return plist.size();
}

std::vector<const Type*> TypeList::getVec() const
{
    return plist;
}

SDO_API void TypeList::insert (const Type* t) 
{
    plist.insert(plist.end(),t);
}

};
};

==> SCA_SDO-1.1.2.tgz: SCA_SDO-1.1.2/commonj/sdo/TypeList.cpp <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 *   
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/* $Rev: 479634 $ $Date: 2006/12/07 12:23:05 $ */

#ifndef SDO_EXPORTS
    #define SDO_EXPORTS
#endif

#include "commonj/sdo/export.h"
#include <iostream>
#include "commonj/sdo/Property.h"
#include "commonj/sdo/Type.h"
#include "commonj/sdo/TypeList.h"
#include "commonj/sdo/Logger.h"

using namespace std;

namespace commonj{
namespace sdo {


/** TypeList provides access to a list of Types.
 *
 * The data factory can return a list of types available. This
 * class wraps that list and provides access to Types by 
 * iteration
 */

SDO_API TypeList::TypeList(std::vector<const Type*> p) : plist (p)
{
}

SDO_API TypeList::TypeList(const TypeList &pin)
{
    plist = std::vector<const Type*>(pin.getVec());
}

SDO_API TypeList::TypeList()
{
}

SDO_API TypeList::~TypeList()
{
}


SDO_API const Type& TypeList::operator[] (unsigned int pos) const
{
    return *plist[pos];
}

SDO_API unsigned int TypeList::size () const
{
    return plist.size();
}

std::vector<const Type*> TypeList::getVec() const
{
    return plist;
}

SDO_API void TypeList::insert (const Type* t) 
{
    plist.insert(plist.end(),t);
}

};
};
